@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudtrail._jsii
 import aws_cdk.aws_cloudwatch._jsii
@@ -24,9 +24,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-s3-step-function",
-    "1.61.0",
+    "1.61.1",
     __name__[0:-6],
-    "aws-s3-step-function@1.61.0.jsii.tgz",
+    "aws-s3-step-function@1.61.1.jsii.tgz",
 )
 
 __all__ = [
